from . import db, dt, scraper

def t():
    return 'works on pypi2'